@@ -38,6 +38,13 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
         # NetApp driver supports updating security service for in use share
         # networks.
         self.security_service_update_support = True
+        self.dhss_mandatory_security_service_association = {
+            'nfs': None,
+            'cifs': ['active_directory', ]
+        }
+        # NetApp driver supports multiple subnets including update existing
+        # share servers.
+        self.network_allocation_update_support = True
 
     def do_setup(self, context):
         self.library.do_setup(context)
@@ -109,13 +116,13 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
 
     def _update_share_stats(self, data=None):
         data = self.library.get_share_stats(
-            filter_function=self.get_filter_function(),
+            get_filter_function=self.get_filter_function,
             goodness_function=self.get_goodness_function())
         super(NetAppCmodeMultiSvmShareDriver, self)._update_share_stats(
             data=data)
 
-    def get_default_filter_function(self):
-        return self.library.get_default_filter_function()
+    def get_default_filter_function(self, pool=None):
+        return self.library.get_default_filter_function(pool=pool)
 
     def get_default_goodness_function(self):
         return self.library.get_default_goodness_function()
@@ -147,10 +154,12 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
                                     replica_snapshots)
 
     def promote_replica(self, context, replica_list, replica, access_rules,
-                        share_server=None):
-        return self.library.promote_replica(context, replica_list, replica,
-                                            access_rules,
-                                            share_server=share_server)
+                        share_server=None, quiesce_wait_time=None):
+        return self.library.promote_replica(
+            context, replica_list, replica,
+            access_rules,
+            share_server=share_server,
+            quiesce_wait_time=quiesce_wait_time)
 
     def update_replica_state(self, context, replica_list, replica,
                              access_rules, replica_snapshots,
@@ -300,7 +309,7 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
 
     def share_server_migration_start(self, context, src_share_server,
                                      dest_share_server, shares, snapshots):
-        self.library.share_server_migration_start(
+        return self.library.share_server_migration_start(
             context, src_share_server, dest_share_server, shares, snapshots)
 
     def share_server_migration_continue(self, context, src_share_server,
@@ -355,3 +364,42 @@ class NetAppCmodeMultiSvmShareDriver(driver.ShareDriver):
         return self.library.check_update_share_server_security_service(
             context, share_server, network_info, new_security_service,
             current_security_service=current_security_service)
+
+    def check_update_share_server_network_allocations(
+            self, context, share_server, current_network_allocations,
+            new_share_network_subnet, security_services, share_instances,
+            share_instances_rules):
+        return self.library.check_update_share_server_network_allocations(
+            context, share_server, current_network_allocations,
+            new_share_network_subnet, security_services, share_instances,
+            share_instances_rules)
+
+    def update_share_server_network_allocations(
+            self, context, share_server, current_network_allocations,
+            new_network_allocations, security_services, shares, snapshots):
+        return self.library.update_share_server_network_allocations(
+            context, share_server, current_network_allocations,
+            new_network_allocations, security_services, shares, snapshots)
+
+    def create_backup(self, context, share, backup, **kwargs):
+        return self.library.create_backup(context, share, backup, **kwargs)
+
+    def create_backup_continue(self, context, share, backup, **kwargs):
+        return self.library.create_backup_continue(context, share, backup,
+                                                   **kwargs)
+
+    def restore_backup(self, context, backup, share, **kwargs):
+        return self.library.restore_backup(context, backup, share,
+                                           **kwargs)
+
+    def restore_backup_continue(self, context, backup, share, **kwargs):
+        return self.library.restore_backup_continue(context, backup, share,
+                                                    **kwargs)
+
+    def delete_backup(self, context, backup, share, **kwargs):
+        return self.library.delete_backup(context, backup, share, **kwargs)
+
+    def update_share_from_metadata(self, context, share, metadata,
+                                   share_server=None):
+        self.library.update_share_from_metadata(
+            context, share, metadata, share_server=share_server)
